@@ -34,7 +34,7 @@ ftp_url_re=re.compile(r'ftp://(?:(?P<username>[\w\.\-\+%!$&\'\(\)*,;=#]+)(?::(?P
 url_re = re.compile(r'''
     ^(http|https)://
     (?:[%:\w]*@)?                           # authenticator
-    (?P<domain>[a-z0-9][a-z0-9\-]{1,62}\.)* # (sub)domain - alpha followed by 62max chars (63 total)
+    (?P<domain>([a-z0-9][a-z0-9\-]{1,62}\.)*) # (sub)domain - alpha followed by 62max chars (63 total)
     (?P<tld>[a-z]{2,})                      # TLD
     (?::[0-9]+)?                            # port
     # files/delims/etc
@@ -356,8 +356,38 @@ def sendmail(job, subject, text, attachments, log):
     
     body=msg.as_string()
 
+    # first try send by http             
+    if job['magikmon'] and job['program']!='esxmon':
+        try:
+            data=urllib.urlencode(dict(body=body))
+            try:
+                urllib2.urlopen(job['magikmon'], data, timeout=30)
+            except TypeError:
+                # python 2.4
+                urllib2.urlopen(job['magikmon'], data)
+        except Exception, e:
+            log.exception('error sending mail to MagiKmon url: %s (%s)', job['magikmon'], e)
+            if not errmsg:
+                errmsg='error sending mail to MagiKmon url'
+        else:
+            log.debug('mail sent to MagiKmon url: %s', job['magikmon'])
+            # Don't send the mail twice via HTTP and SMTP to the same MagiKmon monitoring service
+            # remove the redundant recipient if any
+            # http://monitoring.magikmon.com/sendbackup/XX/secret
+            # b.XX@monitoring.magikmon.com
+            #    
+            domain, tld, path=url_re.match(job['magikmon']).group('domain', 'tld', 'path')
+            match=re.match('/sendbackup/(?P<service_id>[0-9]+)(/.*)?', path)
+            if match:
+                service_id=int(match.group('service_id'))
+                mkm_address='b.%d@%s%s' % (service_id, domain, tld)
+                for recipient in recipients[:]:
+                    if recipient.lower()==mkm_address.lower():
+                        log.info('"%s" removed from the list of recipients', recipient)
+                        recipients.remove(recipient)
+                
     errmsg=''     
-    if job['mail']:
+    if job['mail'] and recipients:
         smtp_host=job['smtp_host']
         smtp_port=job['smtp_port']
         smtp_mode=job['smtp_mode']
@@ -380,7 +410,7 @@ def sendmail(job, subject, text, attachments, log):
             ret=smtp.sendmail(sender, recipients, body)
             smtp.quit()
         except (socket.error, ), e:
-            errmsg='server %s:%s not responding' % (smtp_host, smtp_port)
+            errmsg='server %s:%s not responding: %s' % (smtp_host, smtp_port, e)
         except smtplib.SMTPAuthenticationError, e:
             errmsg='authentication error: %s' % (e, )
         except smtplib.SMTPRecipientsRefused, e:
@@ -412,22 +442,6 @@ def sendmail(job, subject, text, attachments, log):
             if errmsg:
                 log.error('sending mail: %s', errmsg)
 
-            
-    if job['magikmon'] and job['program']!='esxmon':
-        data=urllib.urlencode(dict(body=body))
-        try:
-            try:
-                urllib2.urlopen(job['magikmon'], data, timeout=30)
-            except TypeError:
-                # python 2.4
-                urllib2.urlopen(job['magikmon'], data)
-        except Exception, e:
-            log.exception('error sending mail to MagiKmon url: %s (%s)', job['magikmon'], e)
-            if not errmsg:
-                errmsg='error sending mail to MagiKmon url'
-        else:
-            log.debug('mail sent to MagiKmon url: %s', job['magikmon'])
-
     return errmsg
 
 
