@@ -682,7 +682,7 @@ class Ghettovcb(Archiver):
             wait=60
             while not finished:
                 
-                print 'ASX WAIT', wait
+#                print 'ASX WAIT', wait
                 while wait>0 and not finished:
                     time.sleep(1)
                     wait-=1
